# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/data_versioning/data_versioning.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*qwak/data_versioning/data_versioning.proto\x12\x1fqwak.management.data_versioning\"|\n\x0b\x44\x61taTagSpec\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12\x16\n\x0e\x65xtension_type\x18\x04 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x05 \x01(\t\x12\x0c\n\x04path\x18\x06 \x01(\t\"G\n\rDataTagFilter\x12\x16\n\x0ctag_contains\x18\x01 \x01(\tH\x00\x12\x14\n\ntag_prefix\x18\x02 \x01(\tH\x00\x42\x08\n\x06\x66ilterB/\n+com.qwak.ai.management.model_versioning.apiP\x01\x62\x06proto3')



_DATATAGSPEC = DESCRIPTOR.message_types_by_name['DataTagSpec']
_DATATAGFILTER = DESCRIPTOR.message_types_by_name['DataTagFilter']
DataTagSpec = _reflection.GeneratedProtocolMessageType('DataTagSpec', (_message.Message,), {
  'DESCRIPTOR' : _DATATAGSPEC,
  '__module__' : 'qwak.data_versioning.data_versioning_pb2'
  # @@protoc_insertion_point(class_scope:qwak.management.data_versioning.DataTagSpec)
  })
_sym_db.RegisterMessage(DataTagSpec)

DataTagFilter = _reflection.GeneratedProtocolMessageType('DataTagFilter', (_message.Message,), {
  'DESCRIPTOR' : _DATATAGFILTER,
  '__module__' : 'qwak.data_versioning.data_versioning_pb2'
  # @@protoc_insertion_point(class_scope:qwak.management.data_versioning.DataTagFilter)
  })
_sym_db.RegisterMessage(DataTagFilter)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n+com.qwak.ai.management.model_versioning.apiP\001'
  _DATATAGSPEC._serialized_start=79
  _DATATAGSPEC._serialized_end=203
  _DATATAGFILTER._serialized_start=205
  _DATATAGFILTER._serialized_end=276
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/features_operator/v2/features_operator_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.features_operator.v2 import features_operator_pb2 as qwak_dot_features__operator_dot_v2_dot_features__operator__pb2
from _qwak_proto.qwak.feature_store.features import feature_set_pb2 as qwak_dot_feature__store_dot_features_dot_feature__set__pb2
from _qwak_proto.qwak.feature_store.sources import data_source_pb2 as qwak_dot_feature__store_dot_sources_dot_data__source__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9qwak/features_operator/v2/features_operator_service.proto\x12\x19qwak.features_operator.v2\x1a\x31qwak/features_operator/v2/features_operator.proto\x1a-qwak/feature_store/features/feature_set.proto\x1a,qwak/feature_store/sources/data_source.proto\"\x88\x01\n\x19ValidateDataSourceRequest\x12\x44\n\x10\x64\x61ta_source_spec\x18\x01 \x01(\x0b\x32*.qwak.feature.store.sources.DataSourceSpec\x12\x13\n\x0bnum_samples\x18\x02 \x01(\x05\x12\x10\n\x08zip_path\x18\x03 \x01(\t\"\x89\x01\n\x19ValidateFeatureSetRequest\x12\x45\n\x10\x66\x65\x61ture_set_spec\x18\x01 \x01(\x0b\x32+.qwak.feature.store.features.FeatureSetSpec\x12\x10\n\x08zip_path\x18\x02 \x01(\t\x12\x13\n\x0bnum_samples\x18\x03 \x01(\x05\"\xc0\x01\n\x12ValidationResponse\x12P\n\x10success_response\x18\x01 \x01(\x0b\x32\x34.qwak.features_operator.v2.ValidationSuccessResponseH\x00\x12P\n\x10\x66\x61ilure_response\x18\x02 \x01(\x0b\x32\x34.qwak.features_operator.v2.ValidationFailureResponseH\x00\x42\x06\n\x04type2\x8f\x02\n\x17\x46\x65\x61turesOperatorService\x12y\n\x12ValidateDataSource\x12\x34.qwak.features_operator.v2.ValidateDataSourceRequest\x1a-.qwak.features_operator.v2.ValidationResponse\x12y\n\x12ValidateFeatureSet\x12\x34.qwak.features_operator.v2.ValidateFeatureSetRequest\x1a-.qwak.features_operator.v2.ValidationResponseB(\n$com.qwak.ai.features.operator.api.v2P\x01\x62\x06proto3')



_VALIDATEDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['ValidateDataSourceRequest']
_VALIDATEFEATURESETREQUEST = DESCRIPTOR.message_types_by_name['ValidateFeatureSetRequest']
_VALIDATIONRESPONSE = DESCRIPTOR.message_types_by_name['ValidationResponse']
ValidateDataSourceRequest = _reflection.GeneratedProtocolMessageType('ValidateDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEDATASOURCEREQUEST,
  '__module__' : 'qwak.features_operator.v2.features_operator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.features_operator.v2.ValidateDataSourceRequest)
  })
_sym_db.RegisterMessage(ValidateDataSourceRequest)

ValidateFeatureSetRequest = _reflection.GeneratedProtocolMessageType('ValidateFeatureSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEFEATURESETREQUEST,
  '__module__' : 'qwak.features_operator.v2.features_operator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.features_operator.v2.ValidateFeatureSetRequest)
  })
_sym_db.RegisterMessage(ValidateFeatureSetRequest)

ValidationResponse = _reflection.GeneratedProtocolMessageType('ValidationResponse', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATIONRESPONSE,
  '__module__' : 'qwak.features_operator.v2.features_operator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.features_operator.v2.ValidationResponse)
  })
_sym_db.RegisterMessage(ValidationResponse)

_FEATURESOPERATORSERVICE = DESCRIPTOR.services_by_name['FeaturesOperatorService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$com.qwak.ai.features.operator.api.v2P\001'
  _VALIDATEDATASOURCEREQUEST._serialized_start=233
  _VALIDATEDATASOURCEREQUEST._serialized_end=369
  _VALIDATEFEATURESETREQUEST._serialized_start=372
  _VALIDATEFEATURESETREQUEST._serialized_end=509
  _VALIDATIONRESPONSE._serialized_start=512
  _VALIDATIONRESPONSE._serialized_end=704
  _FEATURESOPERATORSERVICE._serialized_start=707
  _FEATURESOPERATORSERVICE._serialized_end=978
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.deployment import deployment_service_pb2 as qwak_dot_deployment_dot_deployment__service__pb2


class DeploymentManagementServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeployModel = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/DeployModel',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.DeployModelRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.DeployModelResponse.FromString,
                )
        self.UndeployModel = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/UndeployModel',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.UndeployModelRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.UndeployModelResponse.FromString,
                )
        self.GetDeploymentStatus = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/GetDeploymentStatus',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentStatusRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentStatusResponse.FromString,
                )
        self.GetDeploymentDetails = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/GetDeploymentDetails',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentDetailsRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentDetailsResponse.FromString,
                )
        self.UpdateDeploymentRuntimeSettings = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/UpdateDeploymentRuntimeSettings',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.UpdateDeploymentRuntimeSettingsRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.UpdateDeploymentRuntimeSettingsResponse.FromString,
                )
        self.GetDeploymentHistory = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/GetDeploymentHistory',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentHistoryRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentHistoryResponse.FromString,
                )
        self.PushEnvironmentDeploymentState = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/PushEnvironmentDeploymentState',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.PushEnvironmentDeploymentStateRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.PushEnvironmentDeploymentStateResponse.FromString,
                )
        self.ApplyModelTraffic = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/ApplyModelTraffic',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.ApplyModelTrafficRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.ApplyModelTrafficResponse.FromString,
                )
        self.GetModelTraffic = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/GetModelTraffic',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.GetModelTrafficRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.GetModelTrafficResponse.FromString,
                )
        self.IsBuildDeployed = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/IsBuildDeployed',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.IsBuildDeployedRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.IsBuildDeployedResponse.FromString,
                )
        self.IsBuildInUse = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/IsBuildInUse',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.IsBuildInUseRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.IsBuildInUseResponse.FromString,
                )
        self.GetDeployment = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/GetDeployment',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentResponse.FromString,
                )
        self.CancelDeployments = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/CancelDeployments',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.CancelDeploymentsRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.CancelDeploymentsResponse.FromString,
                )
        self.ListLiveModelsDeployments = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/ListLiveModelsDeployments',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.ListLiveModelsDeploymentsRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.ListLiveModelsDeploymentsResponse.FromString,
                )


class DeploymentManagementServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeployModel(self, request, context):
        """Deploy specified model to one of the supported downstream tools
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UndeployModel(self, request, context):
        """Undeploy model
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeploymentStatus(self, request, context):
        """Get the status of a deployment. Main use case is deployment status polling
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeploymentDetails(self, request, context):
        """Get model's deployment details
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDeploymentRuntimeSettings(self, request, context):
        """Set the setting on runtime deployed model
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeploymentHistory(self, request, context):
        """Get Deployments history for model
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PushEnvironmentDeploymentState(self, request, context):
        """Push environment deployments status
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApplyModelTraffic(self, request, context):
        """Apply Model Traffic Changes
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelTraffic(self, request, context):
        """Get Model Traffic Variation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IsBuildDeployed(self, request, context):
        """Checks if a build is deployed
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IsBuildInUse(self, request, context):
        """Checks if a build is in use
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeployment(self, request, context):
        """Get specific deployment 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelDeployments(self, request, context):
        """Cancel the deployment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListLiveModelsDeployments(self, request, context):
        """Get Current (deployed or in progress) Deployments For Model
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DeploymentManagementServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DeployModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployModel,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.DeployModelRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.DeployModelResponse.SerializeToString,
            ),
            'UndeployModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UndeployModel,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.UndeployModelRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.UndeployModelResponse.SerializeToString,
            ),
            'GetDeploymentStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeploymentStatus,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentStatusRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentStatusResponse.SerializeToString,
            ),
            'GetDeploymentDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeploymentDetails,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentDetailsRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentDetailsResponse.SerializeToString,
            ),
            'UpdateDeploymentRuntimeSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDeploymentRuntimeSettings,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.UpdateDeploymentRuntimeSettingsRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.UpdateDeploymentRuntimeSettingsResponse.SerializeToString,
            ),
            'GetDeploymentHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeploymentHistory,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentHistoryRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentHistoryResponse.SerializeToString,
            ),
            'PushEnvironmentDeploymentState': grpc.unary_unary_rpc_method_handler(
                    servicer.PushEnvironmentDeploymentState,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.PushEnvironmentDeploymentStateRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.PushEnvironmentDeploymentStateResponse.SerializeToString,
            ),
            'ApplyModelTraffic': grpc.unary_unary_rpc_method_handler(
                    servicer.ApplyModelTraffic,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.ApplyModelTrafficRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.ApplyModelTrafficResponse.SerializeToString,
            ),
            'GetModelTraffic': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelTraffic,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.GetModelTrafficRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.GetModelTrafficResponse.SerializeToString,
            ),
            'IsBuildDeployed': grpc.unary_unary_rpc_method_handler(
                    servicer.IsBuildDeployed,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.IsBuildDeployedRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.IsBuildDeployedResponse.SerializeToString,
            ),
            'IsBuildInUse': grpc.unary_unary_rpc_method_handler(
                    servicer.IsBuildInUse,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.IsBuildInUseRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.IsBuildInUseResponse.SerializeToString,
            ),
            'GetDeployment': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeployment,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentResponse.SerializeToString,
            ),
            'CancelDeployments': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelDeployments,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.CancelDeploymentsRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.CancelDeploymentsResponse.SerializeToString,
            ),
            'ListLiveModelsDeployments': grpc.unary_unary_rpc_method_handler(
                    servicer.ListLiveModelsDeployments,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.ListLiveModelsDeploymentsRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.ListLiveModelsDeploymentsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.deployment.management.DeploymentManagementService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DeploymentManagementService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeployModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/DeployModel',
            qwak_dot_deployment_dot_deployment__service__pb2.DeployModelRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.DeployModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UndeployModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/UndeployModel',
            qwak_dot_deployment_dot_deployment__service__pb2.UndeployModelRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.UndeployModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeploymentStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/GetDeploymentStatus',
            qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentStatusRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeploymentDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/GetDeploymentDetails',
            qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentDetailsRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentDetailsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDeploymentRuntimeSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/UpdateDeploymentRuntimeSettings',
            qwak_dot_deployment_dot_deployment__service__pb2.UpdateDeploymentRuntimeSettingsRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.UpdateDeploymentRuntimeSettingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeploymentHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/GetDeploymentHistory',
            qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentHistoryRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentHistoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PushEnvironmentDeploymentState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/PushEnvironmentDeploymentState',
            qwak_dot_deployment_dot_deployment__service__pb2.PushEnvironmentDeploymentStateRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.PushEnvironmentDeploymentStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ApplyModelTraffic(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/ApplyModelTraffic',
            qwak_dot_deployment_dot_deployment__service__pb2.ApplyModelTrafficRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.ApplyModelTrafficResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelTraffic(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/GetModelTraffic',
            qwak_dot_deployment_dot_deployment__service__pb2.GetModelTrafficRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.GetModelTrafficResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IsBuildDeployed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/IsBuildDeployed',
            qwak_dot_deployment_dot_deployment__service__pb2.IsBuildDeployedRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.IsBuildDeployedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IsBuildInUse(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/IsBuildInUse',
            qwak_dot_deployment_dot_deployment__service__pb2.IsBuildInUseRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.IsBuildInUseResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeployment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/GetDeployment',
            qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelDeployments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/CancelDeployments',
            qwak_dot_deployment_dot_deployment__service__pb2.CancelDeploymentsRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.CancelDeploymentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListLiveModelsDeployments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/ListLiveModelsDeployments',
            qwak_dot_deployment_dot_deployment__service__pb2.ListLiveModelsDeploymentsRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.ListLiveModelsDeploymentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.inference.feedback import feedback_pb2 as qwak_dot_inference_dot_feedback_dot_feedback__pb2


class FeedbackServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.PostFeedback = channel.unary_unary(
                '/com.qwak.ai.feedback.api.FeedbackService/PostFeedback',
                request_serializer=qwak_dot_inference_dot_feedback_dot_feedback__pb2.ActualValuesRequest.SerializeToString,
                response_deserializer=qwak_dot_inference_dot_feedback_dot_feedback__pb2.ActualValuesResponse.FromString,
                )
        self.ConfigureFeedback = channel.unary_unary(
                '/com.qwak.ai.feedback.api.FeedbackService/ConfigureFeedback',
                request_serializer=qwak_dot_inference_dot_feedback_dot_feedback__pb2.ConfigureFeedbackRequest.SerializeToString,
                response_deserializer=qwak_dot_inference_dot_feedback_dot_feedback__pb2.ConfigureFeedbackResponse.FromString,
                )


class FeedbackServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def PostFeedback(self, request, context):
        """Post feedback values.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureFeedback(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FeedbackServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'PostFeedback': grpc.unary_unary_rpc_method_handler(
                    servicer.PostFeedback,
                    request_deserializer=qwak_dot_inference_dot_feedback_dot_feedback__pb2.ActualValuesRequest.FromString,
                    response_serializer=qwak_dot_inference_dot_feedback_dot_feedback__pb2.ActualValuesResponse.SerializeToString,
            ),
            'ConfigureFeedback': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureFeedback,
                    request_deserializer=qwak_dot_inference_dot_feedback_dot_feedback__pb2.ConfigureFeedbackRequest.FromString,
                    response_serializer=qwak_dot_inference_dot_feedback_dot_feedback__pb2.ConfigureFeedbackResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.qwak.ai.feedback.api.FeedbackService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FeedbackService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def PostFeedback(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.ai.feedback.api.FeedbackService/PostFeedback',
            qwak_dot_inference_dot_feedback_dot_feedback__pb2.ActualValuesRequest.SerializeToString,
            qwak_dot_inference_dot_feedback_dot_feedback__pb2.ActualValuesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureFeedback(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.ai.feedback.api.FeedbackService/ConfigureFeedback',
            qwak_dot_inference_dot_feedback_dot_feedback__pb2.ConfigureFeedbackRequest.SerializeToString,
            qwak_dot_inference_dot_feedback_dot_feedback__pb2.ConfigureFeedbackResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import grpc
from _qwak_proto.qwak.user_application.common.v0.resources_pb2 import (
    ClientPodComputeResources,
    PodComputeResourceTemplateSpec,
)
from _qwak_proto.qwak.workspace.workspace_pb2 import (
    WorkspaceSpec,
    DefaultWorkspaceDetails,
)
from _qwak_proto.qwak.workspace.workspace_service_pb2 import (
    CreateWorkspaceRequest,
    CreateWorkspaceResponse,
    DeleteWorkspaceRequest,
    DeployWorkspaceRequest,
    DeployWorkspaceResponse,
    GetWorkspaceByIdRequest,
    GetWorkspaceByIdResponse,
    ListWorkspaceImagesRequest,
    ListWorkspaceImagesResponse,
    ListWorkspacesRequest,
    ListWorkspacesResponse,
    UndeployWorkspaceRequest,
    UpdateWorkspaceRequest,
    GetDefaultWorkspaceValuesRequest,
    MarkBuildAsCopiedRequest,
)
from _qwak_proto.qwak.workspace.workspace_service_pb2_grpc import (
    WorkspaceManagementServiceStub,
)
from dependency_injector.wiring import Provide
from qwak.exceptions import QwakException
from qwak.inner.di_configuration import QwakContainer


class WorkspaceManagerClient:
    """
    Used for interacting with Workspace Manager endpoints
    """

    def __init__(self, grpc_channel=Provide[QwakContainer.core_grpc_channel]):
        self._workspace_manager = WorkspaceManagementServiceStub(grpc_channel)

    def create_workspace(
        self, workspace_name: str, image_id: str, template_id: str
    ) -> CreateWorkspaceResponse:
        """
        Args:
            workspace_name: The name of the workspace
            image_id: The image id of the workspace deployment
            template_id: The id of the template to use for the workspace deployment

        Returns:
            The response of the created workspace
        """
        try:
            create_workspace_request = CreateWorkspaceRequest(
                workspace_spec=WorkspaceSpec(
                    workspace_name=workspace_name,
                    image_id=image_id,
                    client_pod_compute_resources=ClientPodComputeResources(
                        template_spec=PodComputeResourceTemplateSpec(
                            template_id=template_id
                        )
                    ),
                )
            )
            return self._workspace_manager.CreateWorkspace(create_workspace_request)
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to create workspace,  code: {e.code().name} error is {e.details()}"
            )

    def update_workspace(
        self,
        workspace_id: str,
        workspace_name: str = "",
        image_id: str = "",
        template_id: str = "",
    ) -> CreateWorkspaceResponse:
        """
        Args:
            workspace_id: The id of the workspace
            workspace_name: The name of the workspace
            image_id: The image id of the workspace deployment
            template_id: The id of the template to use for the workspace deployment
        Returns:
            The response of the updated workspace
        """
        try:
            update_workspace_request = UpdateWorkspaceRequest(
                workspace_id=workspace_id,
                workspace_spec=WorkspaceSpec(
                    workspace_name=workspace_name,
                    image_id=image_id,
                    client_pod_compute_resources=ClientPodComputeResources(
                        template_spec=PodComputeResourceTemplateSpec(
                            template_id=template_id
                        )
                    ),
                ),
            )
            return self._workspace_manager.UpdateWorkspace(update_workspace_request)
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to update workspace,  code: {e.code().name} error is {e.details()}"
            )

    def deploy_workspace(self, workspace_id: str) -> DeployWorkspaceResponse:
        """
        Args:
            workspace_id: The id of the workspace
        Returns:
            The response of the deployed workspace
        """
        try:
            deploy_workspace_request = DeployWorkspaceRequest(workspace_id=workspace_id)
            return self._workspace_manager.DeployWorkspace(deploy_workspace_request)
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to deploy workspace,  code: {e.code().name} error is {e.details()}"
            )

    def get_workspaces(self) -> ListWorkspacesResponse:
        """
        Returns:
            The response of the list workspaces
        """
        try:
            return self._workspace_manager.ListWorkspaces(ListWorkspacesRequest())
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to list workspaces,  code: {e.code().name} error is {e.details()}"
            )

    def get_workspace_by_id(self, workspace_id: str) -> GetWorkspaceByIdResponse:
        """
        Args:
            workspace_id: The id of the workspace
        Returns:
            The response of the workspace
        """
        try:
            return self._workspace_manager.GetWorkspaceById(
                GetWorkspaceByIdRequest(workspace_id=workspace_id)
            )
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to get workspace by id,  code: {e.code().name} error is {e.details()}"
            )

    def delete_workspace(self, workspace_id: str) -> DeployWorkspaceResponse:
        """
        Args:
            workspace_id: The id of the workspace
        Returns:
            The response of the deleted workspace
        """
        try:
            delete_workspace_request = DeleteWorkspaceRequest(workspace_id=workspace_id)
            return self._workspace_manager.DeleteWorkspace(delete_workspace_request)
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to delete workspace, code: {e.code().name} error is {e.details()}"
            )

    def undeploy_workspace(self, workspace_id: str) -> DeployWorkspaceResponse:
        """
        Args:
            workspace_id: The id of the workspace
        Returns:
            The response of the undeployed workspace
        """
        try:
            undeploy_workspace_request = UndeployWorkspaceRequest(
                workspace_id=workspace_id
            )
            return self._workspace_manager.UndeployWorkspace(undeploy_workspace_request)
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to undeploy workspace,  code: {e.code().name} error is {e.details()}"
            )

    def get_workspace_images(self) -> ListWorkspaceImagesResponse:
        """
        Returns:
            The response of the list workspace image
        """
        try:
            return self._workspace_manager.ListWorkspaceImages(
                ListWorkspaceImagesRequest()
            )
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to list workspace image types, code: {e.code().name} error is {e.details()}"
            )

    def get_default_workspace_details(self) -> DefaultWorkspaceDetails:
        """
        Returns:
            The default values to complete in case of missing values
        """
        try:
            return self._workspace_manager.GetDefaultWorkspaceValues(
                GetDefaultWorkspaceValuesRequest()
            ).default_workspace_details
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to get default workspace values, code: {e.code().name} error is {e.details()}"
            )

    def _mark_build_as_copied(self, workspace_id: str, build_id: str) -> None:
        """
        Mark build as copied
        """
        try:
            self._workspace_manager.MarkBuildAsCopied(
                MarkBuildAsCopiedRequest(
                    workspace_id=workspace_id,
                    build_id=build_id,
                )
            )
        except grpc.RpcError as e:
            raise QwakException(f"Failed to mark build as copied, got: {e.details()}")



import uuid

import grpc
from _qwak_proto.qwak.feature_store.entities.entity_pb2 import (
    Entity,
    EntityDefinition,
    EntityMetadata,
    FeatureSetBrief,
)
from _qwak_proto.qwak.feature_store.entities.entity_service_pb2 import (
    CreateEntityResponse,
    DeleteEntityRequest,
    DeleteEntityResponse,
    GetEntityByIdResponse,
    GetEntityByNameResponse,
    ListEntitiesResponse,
)
from _qwak_proto.qwak.feature_store.entities.entity_service_pb2_grpc import (
    EntityServiceServicer,
)


class EntityServiceMock(EntityServiceServicer):
    def __init__(self):
        self._entities_spec = {}
        self._entity_id_name = {}

    def reset_entities(self):
        self._entities_spec.clear()

    def CreateEntity(self, request, context):
        entity_id = str(uuid.uuid4())
        self._entities_spec[request.entity_spec.name] = request.entity_spec
        self._entity_id_name[entity_id] = request.entity_spec.name
        return CreateEntityResponse()

    def DeleteEntity(self, request: DeleteEntityRequest, context):
        entity_id: str = request.entity_id

        if entity_id not in self._entity_id_name.keys():
            context.set_code(grpc.StatusCode.NOT_FOUND)
        else:
            entity_name: str = self._entity_id_name[entity_id]
            del self._entity_id_name[entity_id]
            del self._entities_spec[entity_name]

            return DeleteEntityResponse()

    def GetEntityByName(self, request, context):
        if request.entity_name not in self._entities_spec:
            context.set_code(grpc.StatusCode.NOT_FOUND)
            return GetEntityByNameResponse()
        else:
            entity_key: str = list(self._entity_id_name.keys())[
                list(self._entity_id_name.values()).index(request.entity_name)
            ]
            return GetEntityByNameResponse(
                entity=Entity(
                    entity_definition=EntityDefinition(
                        entity_id=entity_key,
                        entity_spec=self._entities_spec[request.entity_name],
                    ),
                    metadata=None,
                    feature_sets=[],
                )
            )

    def GetEntityById(self, request, context):
        if request.entity_id not in self._entity_id_name:
            context.set_code(grpc.StatusCode.NOT_FOUND)
            return GetEntityByIdResponse()
        else:
            entity_name: str = self._entity_id_name[request.entity_id]
            return GetEntityByIdResponse(
                entity=Entity(
                    entity_definition=EntityDefinition(
                        entity_id=request.entity_id,
                        entity_spec=self._entities_spec[entity_name],
                    ),
                    metadata=None,
                    feature_sets=[],
                )
            )

    def ListEntities(self, request, context):
        return ListEntitiesResponse(
            entities=[
                Entity(
                    entity_definition=EntityDefinition(
                        entity_spec=self._entities_spec[entity_name],
                        entity_id=entity_id,
                    ),
                    metadata=EntityMetadata(),
                    feature_sets=[FeatureSetBrief()],
                )
                for entity_id, entity_name in self._entity_id_name.items()
            ]
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/kube_deployment_captain/alert.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(qwak/kube_deployment_captain/alert.proto\x12\x1cqwak.kube.deployment.captain\"\x87\x01\n\rKubeAlertRule\x12\x1d\n\x15notification_channels\x18\x02 \x03(\t\x12?\n\nalert_spec\x18\x03 \x01(\x0b\x32+.qwak.kube.deployment.captain.KubeAlertSpec\x12\x16\n\x0evariation_name\x18\x04 \x01(\t\"\xc0\x02\n\rKubeAlertSpec\x12K\n\x10reducer_function\x18\x01 \x01(\x0e\x32\x31.qwak.kube.deployment.captain.KubeReducerFunction\x12G\n\x0e\x65valuator_type\x18\x02 \x01(\x0e\x32/.qwak.kube.deployment.captain.KubeEvaluatorType\x12\x1f\n\x13\x65valuator_threshold\x18\x03 \x01(\x05\x42\x02\x18\x01\x12\x19\n\x11\x65valuation_period\x18\x04 \x01(\x05\x12?\n\nalert_type\x18\x05 \x01(\x0e\x32+.qwak.kube.deployment.captain.KubeAlertType\x12\x1c\n\x14\x65valuation_threshold\x18\x06 \x01(\x02\"\xae\x01\n\x17KubeNotificationChannel\x12\x1f\n\x17notification_channel_id\x18\x01 \x01(\t\x12!\n\x19notification_channel_name\x18\x02 \x01(\t\x12O\n\x08settings\x18\x03 \x01(\x0b\x32=.qwak.kube.deployment.captain.KubeNotificationChannelSettings\"\xef\x01\n\x1fKubeNotificationChannelSettings\x12\\\n\x0eslack_settings\x18\x01 \x01(\x0b\x32\x42.qwak.kube.deployment.captain.KubeSlackNotificationChannelSettingsH\x00\x12\x62\n\x11opsgenie_settings\x18\x02 \x01(\x0b\x32\x45.qwak.kube.deployment.captain.KubeOpsgenieNotificationChannelSettingsH\x00\x42\n\n\x08settings\"H\n$KubeSlackNotificationChannelSettings\x12 \n\x18notification_channel_url\x18\x01 \x01(\t\"K\n\'KubeOpsgenieNotificationChannelSettings\x12\x0f\n\x07\x61pi_url\x18\x01 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x02 \x01(\t*v\n\rKubeAlertType\x12\x18\n\x14\x41LERT_TYPE_NOT_VALID\x10\x00\x12\x0e\n\nERROR_RATE\x10\x01\x12\x0e\n\nTHROUGHPUT\x10\x02\x12\x0b\n\x07LATENCY\x10\x03\x12\x0e\n\nLATENCY_90\x10\x04\x12\x0e\n\nLATENCY_95\x10\x05*\xb1\x01\n\x13KubeReducerFunction\x12\x1e\n\x1aREDUCER_FUNCTION_NOT_VALID\x10\x00\x12\x07\n\x03MIN\x10\x01\x12\x07\n\x03MAX\x10\x02\x12\x07\n\x03SUM\x10\x03\x12\t\n\x05\x43OUNT\x10\x04\x12\x08\n\x04LAST\x10\x05\x12\n\n\x06MEDIAN\x10\x06\x12\x08\n\x04\x44IFF\x10\x07\x12\x0c\n\x08\x44IFF_ABS\x10\x08\x12\x10\n\x0cPERCENT_DIFF\x10\t\x12\x14\n\x10PERCENT_DIFF_ABS\x10\n*M\n\x11KubeEvaluatorType\x12\x1c\n\x18\x45VALUATOR_TYPE_NOT_VALID\x10\x00\x12\x0c\n\x08IS_ABOVE\x10\x01\x12\x0c\n\x08IS_BELOW\x10\x02\x42+\n\'com.qwak.ai.kube.deployment.captain.apiP\x01\x62\x06proto3')

_KUBEALERTTYPE = DESCRIPTOR.enum_types_by_name['KubeAlertType']
KubeAlertType = enum_type_wrapper.EnumTypeWrapper(_KUBEALERTTYPE)
_KUBEREDUCERFUNCTION = DESCRIPTOR.enum_types_by_name['KubeReducerFunction']
KubeReducerFunction = enum_type_wrapper.EnumTypeWrapper(_KUBEREDUCERFUNCTION)
_KUBEEVALUATORTYPE = DESCRIPTOR.enum_types_by_name['KubeEvaluatorType']
KubeEvaluatorType = enum_type_wrapper.EnumTypeWrapper(_KUBEEVALUATORTYPE)
ALERT_TYPE_NOT_VALID = 0
ERROR_RATE = 1
THROUGHPUT = 2
LATENCY = 3
LATENCY_90 = 4
LATENCY_95 = 5
REDUCER_FUNCTION_NOT_VALID = 0
MIN = 1
MAX = 2
SUM = 3
COUNT = 4
LAST = 5
MEDIAN = 6
DIFF = 7
DIFF_ABS = 8
PERCENT_DIFF = 9
PERCENT_DIFF_ABS = 10
EVALUATOR_TYPE_NOT_VALID = 0
IS_ABOVE = 1
IS_BELOW = 2


_KUBEALERTRULE = DESCRIPTOR.message_types_by_name['KubeAlertRule']
_KUBEALERTSPEC = DESCRIPTOR.message_types_by_name['KubeAlertSpec']
_KUBENOTIFICATIONCHANNEL = DESCRIPTOR.message_types_by_name['KubeNotificationChannel']
_KUBENOTIFICATIONCHANNELSETTINGS = DESCRIPTOR.message_types_by_name['KubeNotificationChannelSettings']
_KUBESLACKNOTIFICATIONCHANNELSETTINGS = DESCRIPTOR.message_types_by_name['KubeSlackNotificationChannelSettings']
_KUBEOPSGENIENOTIFICATIONCHANNELSETTINGS = DESCRIPTOR.message_types_by_name['KubeOpsgenieNotificationChannelSettings']
KubeAlertRule = _reflection.GeneratedProtocolMessageType('KubeAlertRule', (_message.Message,), {
  'DESCRIPTOR' : _KUBEALERTRULE,
  '__module__' : 'qwak.kube_deployment_captain.alert_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.KubeAlertRule)
  })
_sym_db.RegisterMessage(KubeAlertRule)

KubeAlertSpec = _reflection.GeneratedProtocolMessageType('KubeAlertSpec', (_message.Message,), {
  'DESCRIPTOR' : _KUBEALERTSPEC,
  '__module__' : 'qwak.kube_deployment_captain.alert_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.KubeAlertSpec)
  })
_sym_db.RegisterMessage(KubeAlertSpec)

KubeNotificationChannel = _reflection.GeneratedProtocolMessageType('KubeNotificationChannel', (_message.Message,), {
  'DESCRIPTOR' : _KUBENOTIFICATIONCHANNEL,
  '__module__' : 'qwak.kube_deployment_captain.alert_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.KubeNotificationChannel)
  })
_sym_db.RegisterMessage(KubeNotificationChannel)

KubeNotificationChannelSettings = _reflection.GeneratedProtocolMessageType('KubeNotificationChannelSettings', (_message.Message,), {
  'DESCRIPTOR' : _KUBENOTIFICATIONCHANNELSETTINGS,
  '__module__' : 'qwak.kube_deployment_captain.alert_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.KubeNotificationChannelSettings)
  })
_sym_db.RegisterMessage(KubeNotificationChannelSettings)

KubeSlackNotificationChannelSettings = _reflection.GeneratedProtocolMessageType('KubeSlackNotificationChannelSettings', (_message.Message,), {
  'DESCRIPTOR' : _KUBESLACKNOTIFICATIONCHANNELSETTINGS,
  '__module__' : 'qwak.kube_deployment_captain.alert_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.KubeSlackNotificationChannelSettings)
  })
_sym_db.RegisterMessage(KubeSlackNotificationChannelSettings)

KubeOpsgenieNotificationChannelSettings = _reflection.GeneratedProtocolMessageType('KubeOpsgenieNotificationChannelSettings', (_message.Message,), {
  'DESCRIPTOR' : _KUBEOPSGENIENOTIFICATIONCHANNELSETTINGS,
  '__module__' : 'qwak.kube_deployment_captain.alert_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.KubeOpsgenieNotificationChannelSettings)
  })
_sym_db.RegisterMessage(KubeOpsgenieNotificationChannelSettings)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'com.qwak.ai.kube.deployment.captain.apiP\001'
  _KUBEALERTSPEC.fields_by_name['evaluator_threshold']._options = None
  _KUBEALERTSPEC.fields_by_name['evaluator_threshold']._serialized_options = b'\030\001'
  _KUBEALERTTYPE._serialized_start=1105
  _KUBEALERTTYPE._serialized_end=1223
  _KUBEREDUCERFUNCTION._serialized_start=1226
  _KUBEREDUCERFUNCTION._serialized_end=1403
  _KUBEEVALUATORTYPE._serialized_start=1405
  _KUBEEVALUATORTYPE._serialized_end=1482
  _KUBEALERTRULE._serialized_start=75
  _KUBEALERTRULE._serialized_end=210
  _KUBEALERTSPEC._serialized_start=213
  _KUBEALERTSPEC._serialized_end=533
  _KUBENOTIFICATIONCHANNEL._serialized_start=536
  _KUBENOTIFICATIONCHANNEL._serialized_end=710
  _KUBENOTIFICATIONCHANNELSETTINGS._serialized_start=713
  _KUBENOTIFICATIONCHANNELSETTINGS._serialized_end=952
  _KUBESLACKNOTIFICATIONCHANNELSETTINGS._serialized_start=954
  _KUBESLACKNOTIFICATIONCHANNELSETTINGS._serialized_end=1026
  _KUBEOPSGENIENOTIFICATIONCHANNELSETTINGS._serialized_start=1028
  _KUBEOPSGENIENOTIFICATIONCHANNELSETTINGS._serialized_end=1103
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class OpenAIIntegration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPENAI_API_KEY_SYSTEM_SECRET_DESCRIPTOR_FIELD_NUMBER: builtins.int
    @property
    def openai_api_key_system_secret_descriptor(self) -> global___OpenAIApiKeySystemSecretDescriptor:
        """OpenAI system secret descriptor"""
    def __init__(
        self,
        *,
        openai_api_key_system_secret_descriptor: global___OpenAIApiKeySystemSecretDescriptor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "openai_api_key_system_secret_descriptor", b"openai_api_key_system_secret_descriptor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "openai_api_key_system_secret_descriptor", b"openai_api_key_system_secret_descriptor"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["openai_api_key_system_secret_descriptor"] | None: ...

global___OpenAIIntegration = OpenAIIntegration

class OpenAIIntegrationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPENAI_API_KEY_AUTH_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def openai_api_key_auth_config(self) -> global___OpenAIApiKeyAuthConfig: ...
    def __init__(
        self,
        *,
        openai_api_key_auth_config: global___OpenAIApiKeyAuthConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "openai_api_key_auth_config", b"openai_api_key_auth_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "openai_api_key_auth_config", b"openai_api_key_auth_config"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["openai_api_key_auth_config"] | None: ...

global___OpenAIIntegrationSpec = OpenAIIntegrationSpec

class OpenAIApiKeyAuthConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_KEY_FIELD_NUMBER: builtins.int
    api_key: builtins.str
    def __init__(
        self,
        *,
        api_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_key", b"api_key"]) -> None: ...

global___OpenAIApiKeyAuthConfig = OpenAIApiKeyAuthConfig

class OpenAIApiKeySystemSecretDescriptor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_NAME_FIELD_NUMBER: builtins.int
    API_KEY_SECRET_KEY_FIELD_NUMBER: builtins.int
    secret_name: builtins.str
    """OpenAI system secret name"""
    api_key_secret_key: builtins.str
    """OpenAI system secret api_key secret key"""
    def __init__(
        self,
        *,
        secret_name: builtins.str = ...,
        api_key_secret_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_key_secret_key", b"api_key_secret_key", "secret_name", b"secret_name"]) -> None: ...

global___OpenAIApiKeySystemSecretDescriptor = OpenAIApiKeySystemSecretDescriptor

class OpenAIValidationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPENAI_API_KEY_AUTH_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def openai_api_key_auth_config(self) -> global___OpenAIApiKeyAuthConfig: ...
    def __init__(
        self,
        *,
        openai_api_key_auth_config: global___OpenAIApiKeyAuthConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "openai_api_key_auth_config", b"openai_api_key_auth_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "openai_api_key_auth_config", b"openai_api_key_auth_config"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["openai_api_key_auth_config"] | None: ...

global___OpenAIValidationSpec = OpenAIValidationSpec

class OpenAIIntegrationOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___OpenAIIntegrationOptions = OpenAIIntegrationOptions



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/offline/serving/v1/offline_serving_async_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.offline.serving.v1 import population_pb2 as qwak_dot_offline_dot_serving_dot_v1_dot_population__pb2
from _qwak_proto.qwak.offline.serving.v1 import feature_values_pb2 as qwak_dot_offline_dot_serving_dot_v1_dot_feature__values__pb2
from _qwak_proto.qwak.offline.serving.v1 import options_pb2 as qwak_dot_offline_dot_serving_dot_v1_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;qwak/offline/serving/v1/offline_serving_async_service.proto\x12%qwak.feature.store.offline.serving.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a(qwak/offline/serving/v1/population.proto\x1a,qwak/offline/serving/v1/feature_values.proto\x1a%qwak/offline/serving/v1/options.proto\"{\n\x17GetFileUploadUrlRequest\x12X\n\npopulation\x18\x01 \x01(\x0b\x32\x42.qwak.feature.store.offline.serving.v1.PopulationFileUploadUrlTypeH\x00\x42\x06\n\x04type\"3\n\x18GetFileUploadUrlResponse\x12\x17\n\x0f\x66ile_upload_url\x18\x01 \x01(\t\"\xd5\x02\n\x17GetFeatureValuesRequest\x12K\n\x08\x66\x65\x61tures\x18\x01 \x03(\x0b\x32\x39.qwak.feature.store.offline.serving.v1.FeaturesetFeatures\x12J\n\npopulation\x18\x02 \x01(\x0b\x32\x36.qwak.feature.store.offline.serving.v1.TimedPopulation\x12M\n\x12result_file_format\x18\x03 \x01(\x0e\x32\x31.qwak.feature.store.offline.serving.v1.FileFormat\x12R\n\x07options\x18\x04 \x01(\x0b\x32\x41.qwak.feature.store.offline.serving.v1.OfflineServingQueryOptions\".\n\x18GetFeatureValuesResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\"\xdc\x03\n\x1eGetFeatureValuesInRangeRequest\x12K\n\x08\x66\x65\x61tures\x18\x01 \x01(\x0b\x32\x39.qwak.feature.store.offline.serving.v1.FeaturesetFeatures\x12\x34\n\x10lower_time_bound\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10upper_time_bound\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12G\n\npopulation\x18\x04 \x01(\x0b\x32\x31.qwak.feature.store.offline.serving.v1.PopulationH\x00\x12M\n\x12result_file_format\x18\x05 \x01(\x0e\x32\x31.qwak.feature.store.offline.serving.v1.FileFormat\x12R\n\x07options\x18\x06 \x01(\x0b\x32\x41.qwak.feature.store.offline.serving.v1.OfflineServingQueryOptionsB\x15\n\x13optional_population\"5\n\x1fGetFeatureValuesInRangeResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\"3\n\x1dGetFeatureValuesResultRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\t\"\x9b\x02\n\x1eGetFeatureValuesResultResponse\x12Q\n\x06status\x18\x01 \x01(\x0e\x32\x41.qwak.feature.store.offline.serving.v1.FeatureValuesRequestStatus\x12K\n\rlink_to_files\x18\x02 \x01(\x0b\x32\x32.qwak.feature.store.offline.serving.v1.LinkToFilesH\x00\x12N\n\x0e\x66\x61ilure_reason\x18\x03 \x01(\x0b\x32\x34.qwak.feature.store.offline.serving.v1.FailureReasonH\x00\x42\t\n\x07payload\" \n\rFailureReason\x12\x0f\n\x07message\x18\x01 \x01(\t\"$\n\x0bLinkToFiles\x12\x15\n\rlink_to_files\x18\x01 \x03(\t*\xf6\x01\n\x1a\x46\x65\x61tureValuesRequestStatus\x12)\n%FEATURE_VALUES_REQUEST_STATUS_INVALID\x10\x00\x12+\n\'FEATURE_VALUES_REQUEST_STATUS_SUCCEEDED\x10\x01\x12)\n%FEATURE_VALUES_REQUEST_STATUS_PENDING\x10\x02\x12+\n\'FEATURE_VALUES_REQUEST_STATUS_CANCELLED\x10\x03\x12(\n$FEATURE_VALUES_REQUEST_STATUS_FAILED\x10\x04*:\n\nFileFormat\x12\x17\n\x13\x46ILE_FORMAT_INVALID\x10\x00\x12\x13\n\x0f\x46ILE_FORMAT_CSV\x10\x01\x32\xa7\x05\n&FeatureStoreOfflineServingAsyncService\x12\x93\x01\n\x10GetFileUploadUrl\x12>.qwak.feature.store.offline.serving.v1.GetFileUploadUrlRequest\x1a?.qwak.feature.store.offline.serving.v1.GetFileUploadUrlResponse\x12\x93\x01\n\x10GetFeatureValues\x12>.qwak.feature.store.offline.serving.v1.GetFeatureValuesRequest\x1a?.qwak.feature.store.offline.serving.v1.GetFeatureValuesResponse\x12\xa8\x01\n\x17GetFeatureValuesInRange\x12\x45.qwak.feature.store.offline.serving.v1.GetFeatureValuesInRangeRequest\x1a\x46.qwak.feature.store.offline.serving.v1.GetFeatureValuesInRangeResponse\x12\xa5\x01\n\x16GetFeatureValuesResult\x12\x44.qwak.feature.store.offline.serving.v1.GetFeatureValuesResultRequest\x1a\x45.qwak.feature.store.offline.serving.v1.GetFeatureValuesResultResponseB&\n\"com.qwak.ai.offline.serving.api.v1P\x01\x62\x06proto3')

_FEATUREVALUESREQUESTSTATUS = DESCRIPTOR.enum_types_by_name['FeatureValuesRequestStatus']
FeatureValuesRequestStatus = enum_type_wrapper.EnumTypeWrapper(_FEATUREVALUESREQUESTSTATUS)
_FILEFORMAT = DESCRIPTOR.enum_types_by_name['FileFormat']
FileFormat = enum_type_wrapper.EnumTypeWrapper(_FILEFORMAT)
FEATURE_VALUES_REQUEST_STATUS_INVALID = 0
FEATURE_VALUES_REQUEST_STATUS_SUCCEEDED = 1
FEATURE_VALUES_REQUEST_STATUS_PENDING = 2
FEATURE_VALUES_REQUEST_STATUS_CANCELLED = 3
FEATURE_VALUES_REQUEST_STATUS_FAILED = 4
FILE_FORMAT_INVALID = 0
FILE_FORMAT_CSV = 1


_GETFILEUPLOADURLREQUEST = DESCRIPTOR.message_types_by_name['GetFileUploadUrlRequest']
_GETFILEUPLOADURLRESPONSE = DESCRIPTOR.message_types_by_name['GetFileUploadUrlResponse']
_GETFEATUREVALUESREQUEST = DESCRIPTOR.message_types_by_name['GetFeatureValuesRequest']
_GETFEATUREVALUESRESPONSE = DESCRIPTOR.message_types_by_name['GetFeatureValuesResponse']
_GETFEATUREVALUESINRANGEREQUEST = DESCRIPTOR.message_types_by_name['GetFeatureValuesInRangeRequest']
_GETFEATUREVALUESINRANGERESPONSE = DESCRIPTOR.message_types_by_name['GetFeatureValuesInRangeResponse']
_GETFEATUREVALUESRESULTREQUEST = DESCRIPTOR.message_types_by_name['GetFeatureValuesResultRequest']
_GETFEATUREVALUESRESULTRESPONSE = DESCRIPTOR.message_types_by_name['GetFeatureValuesResultResponse']
_FAILUREREASON = DESCRIPTOR.message_types_by_name['FailureReason']
_LINKTOFILES = DESCRIPTOR.message_types_by_name['LinkToFiles']
GetFileUploadUrlRequest = _reflection.GeneratedProtocolMessageType('GetFileUploadUrlRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFILEUPLOADURLREQUEST,
  '__module__' : 'qwak.offline.serving.v1.offline_serving_async_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.offline.serving.v1.GetFileUploadUrlRequest)
  })
_sym_db.RegisterMessage(GetFileUploadUrlRequest)

GetFileUploadUrlResponse = _reflection.GeneratedProtocolMessageType('GetFileUploadUrlResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFILEUPLOADURLRESPONSE,
  '__module__' : 'qwak.offline.serving.v1.offline_serving_async_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.offline.serving.v1.GetFileUploadUrlResponse)
  })
_sym_db.RegisterMessage(GetFileUploadUrlResponse)

GetFeatureValuesRequest = _reflection.GeneratedProtocolMessageType('GetFeatureValuesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREVALUESREQUEST,
  '__module__' : 'qwak.offline.serving.v1.offline_serving_async_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.offline.serving.v1.GetFeatureValuesRequest)
  })
_sym_db.RegisterMessage(GetFeatureValuesRequest)

GetFeatureValuesResponse = _reflection.GeneratedProtocolMessageType('GetFeatureValuesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREVALUESRESPONSE,
  '__module__' : 'qwak.offline.serving.v1.offline_serving_async_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.offline.serving.v1.GetFeatureValuesResponse)
  })
_sym_db.RegisterMessage(GetFeatureValuesResponse)

GetFeatureValuesInRangeRequest = _reflection.GeneratedProtocolMessageType('GetFeatureValuesInRangeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREVALUESINRANGEREQUEST,
  '__module__' : 'qwak.offline.serving.v1.offline_serving_async_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.offline.serving.v1.GetFeatureValuesInRangeRequest)
  })
_sym_db.RegisterMessage(GetFeatureValuesInRangeRequest)

GetFeatureValuesInRangeResponse = _reflection.GeneratedProtocolMessageType('GetFeatureValuesInRangeResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREVALUESINRANGERESPONSE,
  '__module__' : 'qwak.offline.serving.v1.offline_serving_async_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.offline.serving.v1.GetFeatureValuesInRangeResponse)
  })
_sym_db.RegisterMessage(GetFeatureValuesInRangeResponse)

GetFeatureValuesResultRequest = _reflection.GeneratedProtocolMessageType('GetFeatureValuesResultRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREVALUESRESULTREQUEST,
  '__module__' : 'qwak.offline.serving.v1.offline_serving_async_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.offline.serving.v1.GetFeatureValuesResultRequest)
  })
_sym_db.RegisterMessage(GetFeatureValuesResultRequest)

GetFeatureValuesResultResponse = _reflection.GeneratedProtocolMessageType('GetFeatureValuesResultResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREVALUESRESULTRESPONSE,
  '__module__' : 'qwak.offline.serving.v1.offline_serving_async_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.offline.serving.v1.GetFeatureValuesResultResponse)
  })
_sym_db.RegisterMessage(GetFeatureValuesResultResponse)

FailureReason = _reflection.GeneratedProtocolMessageType('FailureReason', (_message.Message,), {
  'DESCRIPTOR' : _FAILUREREASON,
  '__module__' : 'qwak.offline.serving.v1.offline_serving_async_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.offline.serving.v1.FailureReason)
  })
_sym_db.RegisterMessage(FailureReason)

LinkToFiles = _reflection.GeneratedProtocolMessageType('LinkToFiles', (_message.Message,), {
  'DESCRIPTOR' : _LINKTOFILES,
  '__module__' : 'qwak.offline.serving.v1.offline_serving_async_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.offline.serving.v1.LinkToFiles)
  })
_sym_db.RegisterMessage(LinkToFiles)

_FEATURESTOREOFFLINESERVINGASYNCSERVICE = DESCRIPTOR.services_by_name['FeatureStoreOfflineServingAsyncService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"com.qwak.ai.offline.serving.api.v1P\001'
  _FEATUREVALUESREQUESTSTATUS._serialized_start=1778
  _FEATUREVALUESREQUESTSTATUS._serialized_end=2024
  _FILEFORMAT._serialized_start=2026
  _FILEFORMAT._serialized_end=2084
  _GETFILEUPLOADURLREQUEST._serialized_start=262
  _GETFILEUPLOADURLREQUEST._serialized_end=385
  _GETFILEUPLOADURLRESPONSE._serialized_start=387
  _GETFILEUPLOADURLRESPONSE._serialized_end=438
  _GETFEATUREVALUESREQUEST._serialized_start=441
  _GETFEATUREVALUESREQUEST._serialized_end=782
  _GETFEATUREVALUESRESPONSE._serialized_start=784
  _GETFEATUREVALUESRESPONSE._serialized_end=830
  _GETFEATUREVALUESINRANGEREQUEST._serialized_start=833
  _GETFEATUREVALUESINRANGEREQUEST._serialized_end=1309
  _GETFEATUREVALUESINRANGERESPONSE._serialized_start=1311
  _GETFEATUREVALUESINRANGERESPONSE._serialized_end=1364
  _GETFEATUREVALUESRESULTREQUEST._serialized_start=1366
  _GETFEATUREVALUESRESULTREQUEST._serialized_end=1417
  _GETFEATUREVALUESRESULTRESPONSE._serialized_start=1420
  _GETFEATUREVALUESRESULTRESPONSE._serialized_end=1703
  _FAILUREREASON._serialized_start=1705
  _FAILUREREASON._serialized_end=1737
  _LINKTOFILES._serialized_start=1739
  _LINKTOFILES._serialized_end=1775
  _FEATURESTOREOFFLINESERVINGASYNCSERVICE._serialized_start=2087
  _FEATURESTOREOFFLINESERVINGASYNCSERVICE._serialized_end=2766
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class SqlEngineConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATHENA_SQL_ENGINE_CONFIGURATION_FIELD_NUMBER: builtins.int
    BIG_QUERY_SQL_ENGINE_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def athena_sql_engine_configuration(self) -> global___AthenaSqlEngineConfig: ...
    @property
    def big_query_sql_engine_configuration(self) -> global___BigQuerySqlEngineConfig: ...
    def __init__(
        self,
        *,
        athena_sql_engine_configuration: global___AthenaSqlEngineConfig | None = ...,
        big_query_sql_engine_configuration: global___BigQuerySqlEngineConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["athena_sql_engine_configuration", b"athena_sql_engine_configuration", "big_query_sql_engine_configuration", b"big_query_sql_engine_configuration", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["athena_sql_engine_configuration", b"athena_sql_engine_configuration", "big_query_sql_engine_configuration", b"big_query_sql_engine_configuration", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["athena_sql_engine_configuration", "big_query_sql_engine_configuration"] | None: ...

global___SqlEngineConfiguration = SqlEngineConfiguration

class AthenaSqlEngineConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTERNAL_ID_FIELD_NUMBER: builtins.int
    WORKGROUP_FIELD_NUMBER: builtins.int
    external_id: builtins.str
    workgroup: builtins.str
    def __init__(
        self,
        *,
        external_id: builtins.str = ...,
        workgroup: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["external_id", b"external_id", "workgroup", b"workgroup"]) -> None: ...

global___AthenaSqlEngineConfig = AthenaSqlEngineConfig

class BigQuerySqlEngineConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___BigQuerySqlEngineConfig = BigQuerySqlEngineConfig



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.feature_store.v1.common.jfrog_artifact.jfrog_artifact_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class SourceCodeSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARTIFACT_FIELD_NUMBER: builtins.int
    @property
    def artifact(self) -> global___SourceCodeArtifact: ...
    def __init__(
        self,
        *,
        artifact: global___SourceCodeArtifact | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["artifact", b"artifact"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifact", b"artifact"]) -> None: ...

global___SourceCodeSpec = SourceCodeSpec

class SourceCodeArtifact(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ZIP_ARTIFACT_FIELD_NUMBER: builtins.int
    @property
    def zip_artifact(self) -> global___ZipArtifact: ...
    def __init__(
        self,
        *,
        zip_artifact: global___ZipArtifact | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["type", b"type", "zip_artifact", b"zip_artifact"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "zip_artifact", b"zip_artifact"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["zip_artifact"] | None: ...

global___SourceCodeArtifact = SourceCodeArtifact

class ZipArtifact(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    JFROG_ARTIFACT_PATH_FIELD_NUMBER: builtins.int
    MAIN_FILE_FIELD_NUMBER: builtins.int
    path: builtins.str
    """Path to artifact, used by Qwak users e.g: s3://some-bucket/file.zip"""
    @property
    def jfrog_artifact_path(self) -> qwak.feature_store.v1.common.jfrog_artifact.jfrog_artifact_pb2.JfrogArtifact:
        """Path to the artifact stored in Artifactory"""
    main_file: builtins.str
    """Relative path inside the zip, e.g:
    the file the featureset is defined
    """
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        jfrog_artifact_path: qwak.feature_store.v1.common.jfrog_artifact.jfrog_artifact_pb2.JfrogArtifact | None = ...,
        main_file: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["jfrog_artifact_path", b"jfrog_artifact_path", "path", b"path", "path_type", b"path_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["jfrog_artifact_path", b"jfrog_artifact_path", "main_file", b"main_file", "path", b"path", "path_type", b"path_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["path_type", b"path_type"]) -> typing_extensions.Literal["path", "jfrog_artifact_path"] | None: ...

global___ZipArtifact = ZipArtifact



import uuid

from _qwak_proto.qwak.audience.v1.audience_api_pb2 import (
    CreateAudienceRequest,
    CreateAudienceResponse,
    DeleteAudienceRequest,
    DeleteAudienceResponse,
    GetAudienceRequest,
    GetAudienceResponse,
    ListAudienceRequest,
    ListAudienceResponse,
    SyncAudiencesRequest,
    SyncAudiencesResponse,
    UpdateAudienceRequest,
    UpdateAudienceResponse,
)
from _qwak_proto.qwak.audience.v1.audience_api_pb2_grpc import AudienceAPIServicer
from _qwak_proto.qwak.audience.v1.audience_pb2 import AudienceEntry
from qwak_services_mock.mocks.utils.exception_handlers import raise_internal_grpc_error


class AudienceServiceApiMock(AudienceAPIServicer):
    def __init__(self):
        super(AudienceServiceApiMock, self).__init__()
        self.audiences = dict()

    def CreateAudience(
        self, request: CreateAudienceRequest, context
    ) -> CreateAudienceResponse:
        try:
            audience_id = str(uuid.uuid4())
            self.audiences[audience_id] = request.audience
            return CreateAudienceResponse(audience_id=audience_id)
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def UpdateAudience(
        self, request: UpdateAudienceRequest, context
    ) -> UpdateAudienceResponse:
        try:
            self.audiences[request.id] = request.audience
            return UpdateAudienceResponse()
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def GetAudience(self, request: GetAudienceRequest, context) -> GetAudienceResponse:
        try:
            return GetAudienceResponse(audience=self.audiences[request.audience_id])
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def ListAudience(
        self, request: ListAudienceRequest, context
    ) -> ListAudienceResponse:
        try:
            return ListAudienceResponse(
                audience_entries=[
                    AudienceEntry(id=audience_id, audience=audience)
                    for audience_id, audience in self.audiences.items()
                ]
            )
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def DeleteAudience(
        self, request: DeleteAudienceRequest, context
    ) -> DeleteAudienceResponse:
        try:
            del self.audiences[request.audience_id]
            return DeleteAudienceResponse()
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def SyncAudiences(
        self, request: SyncAudiencesRequest, context
    ) -> SyncAudiencesResponse:
        return SyncAudiencesResponse()



from typing import List, Optional

from qwak.inner.build_config.build_config_v1 import BuildConfigV1
from ..interface.build_phase import BuildPhase
from ..interface.context_interface import Context

from qwak.inner.build_logic.interface.step_inteface import Step


class PhasesPipeline:
    def __init__(
        self,
        config: Optional[BuildConfigV1],
        context: Context,
        build_phase: Optional[BuildPhase] = None,
    ) -> None:
        self._phases: List[PhasesPipeline] = []
        self._steps: List[Step] = []
        self.context = context
        self._config = config
        self.build_phase = build_phase

    @property
    def phases(self) -> List["PhasesPipeline"]:
        return self._phases

    @property
    def steps(self) -> List[Step]:
        return self._steps

    def add_phase(self, steps: List[Step], build_phase: BuildPhase):
        phase = PhasesPipeline(
            config=self._config,
            context=self.context,
            build_phase=build_phase,
        )

        for step in steps:
            step.context = self.context
            step.config = self._config
            step.build_phase = build_phase
            phase._steps.append(step)

        self._phases.append(phase)



from types import FunctionType
from typing import Any, Callable


def extract_wrapped(decorated: Callable[..., Any]):
    if decorated.__closure__:
        closure = (c.cell_contents for c in decorated.__closure__)
        return next((c for c in closure if isinstance(c, FunctionType)), decorated)
    return decorated



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.feature_store.entities.entity_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateEntityRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_SPEC_FIELD_NUMBER: builtins.int
    @property
    def entity_spec(self) -> qwak.feature_store.entities.entity_pb2.EntitySpec:
        """Entity specifications to create"""
    def __init__(
        self,
        *,
        entity_spec: qwak.feature_store.entities.entity_pb2.EntitySpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity_spec", b"entity_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity_spec", b"entity_spec"]) -> None: ...

global___CreateEntityRequest = CreateEntityRequest

class UpdateEntityRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_ID_FIELD_NUMBER: builtins.int
    ENTITY_SPEC_FIELD_NUMBER: builtins.int
    entity_id: builtins.str
    """Entity ID to update"""
    @property
    def entity_spec(self) -> qwak.feature_store.entities.entity_pb2.EntitySpec:
        """Entity specifications to update"""
    def __init__(
        self,
        *,
        entity_id: builtins.str = ...,
        entity_spec: qwak.feature_store.entities.entity_pb2.EntitySpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity_spec", b"entity_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity_id", b"entity_id", "entity_spec", b"entity_spec"]) -> None: ...

global___UpdateEntityRequest = UpdateEntityRequest

class UpdateEntityResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_FIELD_NUMBER: builtins.int
    @property
    def entity(self) -> qwak.feature_store.entities.entity_pb2.Entity:
        """The updated entity"""
    def __init__(
        self,
        *,
        entity: qwak.feature_store.entities.entity_pb2.Entity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> None: ...

global___UpdateEntityResponse = UpdateEntityResponse

class CreateEntityResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_FIELD_NUMBER: builtins.int
    @property
    def entity(self) -> qwak.feature_store.entities.entity_pb2.Entity:
        """The newly created entity"""
    def __init__(
        self,
        *,
        entity: qwak.feature_store.entities.entity_pb2.Entity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> None: ...

global___CreateEntityResponse = CreateEntityResponse

class GetEntityByIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_ID_FIELD_NUMBER: builtins.int
    entity_id: builtins.str
    """Id of the requested entity to fetch"""
    def __init__(
        self,
        *,
        entity_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity_id", b"entity_id"]) -> None: ...

global___GetEntityByIdRequest = GetEntityByIdRequest

class GetEntityByIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_FIELD_NUMBER: builtins.int
    @property
    def entity(self) -> qwak.feature_store.entities.entity_pb2.Entity:
        """Fetched entity by the requested id"""
    def __init__(
        self,
        *,
        entity: qwak.feature_store.entities.entity_pb2.Entity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> None: ...

global___GetEntityByIdResponse = GetEntityByIdResponse

class GetEntityByNameRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_NAME_FIELD_NUMBER: builtins.int
    entity_name: builtins.str
    """Name of the requested entity to fetch"""
    def __init__(
        self,
        *,
        entity_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity_name", b"entity_name"]) -> None: ...

global___GetEntityByNameRequest = GetEntityByNameRequest

class GetEntityByNameResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_FIELD_NUMBER: builtins.int
    @property
    def entity(self) -> qwak.feature_store.entities.entity_pb2.Entity:
        """Fetched entity by the requested name"""
    def __init__(
        self,
        *,
        entity: qwak.feature_store.entities.entity_pb2.Entity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> None: ...

global___GetEntityByNameResponse = GetEntityByNameResponse

class DeleteEntityRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_ID_FIELD_NUMBER: builtins.int
    entity_id: builtins.str
    """Id of the entity to be deleted"""
    def __init__(
        self,
        *,
        entity_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity_id", b"entity_id"]) -> None: ...

global___DeleteEntityRequest = DeleteEntityRequest

class DeleteEntityResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteEntityResponse = DeleteEntityResponse

class ListEntitiesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListEntitiesRequest = ListEntitiesRequest

class ListEntitiesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITIES_FIELD_NUMBER: builtins.int
    @property
    def entities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.feature_store.entities.entity_pb2.Entity]:
        """All the entities belonging to the callers' partner id / user id"""
    def __init__(
        self,
        *,
        entities: collections.abc.Iterable[qwak.feature_store.entities.entity_pb2.Entity] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["entities", b"entities"]) -> None: ...

global___ListEntitiesResponse = ListEntitiesResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/ecosystem/jfrog/v0/token_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.ecosystem.jfrog.v0 import token_pb2 as qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+qwak/ecosystem/jfrog/v0/token_service.proto\x12\x1dqwak.ecosystem.jfrog.token.v0\x1a#qwak/ecosystem/jfrog/v0/token.proto\"Y\n\x14GenerateTokenRequest\x12\x41\n\ntoken_spec\x18\x01 \x01(\x0b\x32-.qwak.ecosystem.jfrog.token.v0.JFrogTokenSpec\"Q\n\x15GenerateTokenResponse\x12\x38\n\x05token\x18\x01 \x01(\x0b\x32).qwak.ecosystem.jfrog.token.v0.JFrogToken\"|\n(GenerateArtifactoryImagePullTokenRequest\x12P\n\ntoken_spec\x18\x01 \x01(\x0b\x32<.qwak.ecosystem.jfrog.token.v0.ArtifactoryImagePullTokenSpec\"e\n)GenerateArtifactoryImagePullTokenResponse\x12\x38\n\x05token\x18\x01 \x01(\x0b\x32).qwak.ecosystem.jfrog.token.v0.JFrogToken\"`\n\x19PersistTokenClaimsRequest\x12\x43\n\x04spec\x18\x01 \x01(\x0b\x32\x35.qwak.ecosystem.jfrog.token.v0.PersistTokenClaimsSpec\".\n\x1aPersistTokenClaimsResponse\x12\x10\n\x08token_id\x18\x01 \x01(\t\"d\n\x12RevokeTokenRequest\x12N\n\x11token_revoke_spec\x18\x01 \x01(\x0b\x32\x33.qwak.ecosystem.jfrog.token.v0.JFrogTokenRevokeSpec\"\x1c\n\x1aRevokeTokenRequestResponse2\xcc\x04\n\x0cTokenService\x12z\n\rGenerateToken\x12\x33.qwak.ecosystem.jfrog.token.v0.GenerateTokenRequest\x1a\x34.qwak.ecosystem.jfrog.token.v0.GenerateTokenResponse\x12\xb6\x01\n!GenerateArtifactoryImagePullToken\x12G.qwak.ecosystem.jfrog.token.v0.GenerateArtifactoryImagePullTokenRequest\x1aH.qwak.ecosystem.jfrog.token.v0.GenerateArtifactoryImagePullTokenResponse\x12\x89\x01\n\x12PersistTokenClaims\x12\x38.qwak.ecosystem.jfrog.token.v0.PersistTokenClaimsRequest\x1a\x39.qwak.ecosystem.jfrog.token.v0.PersistTokenClaimsResponse\x12{\n\x0bRevokeToken\x12\x31.qwak.ecosystem.jfrog.token.v0.RevokeTokenRequest\x1a\x39.qwak.ecosystem.jfrog.token.v0.RevokeTokenRequestResponseB\xb7\x01\n\x1a\x63om.qwak.ai.jfrog.token.v0P\x01Z\x96\x01github.com/qwak-ai/qwak-platform/services/shared/java/libs/qwak-common/qwak-common-api/qwak-platform-ecosystem-api/pb/qwak/ecosystem/jfrog/v0;jfrog_v0b\x06proto3')



_GENERATETOKENREQUEST = DESCRIPTOR.message_types_by_name['GenerateTokenRequest']
_GENERATETOKENRESPONSE = DESCRIPTOR.message_types_by_name['GenerateTokenResponse']
_GENERATEARTIFACTORYIMAGEPULLTOKENREQUEST = DESCRIPTOR.message_types_by_name['GenerateArtifactoryImagePullTokenRequest']
_GENERATEARTIFACTORYIMAGEPULLTOKENRESPONSE = DESCRIPTOR.message_types_by_name['GenerateArtifactoryImagePullTokenResponse']
_PERSISTTOKENCLAIMSREQUEST = DESCRIPTOR.message_types_by_name['PersistTokenClaimsRequest']
_PERSISTTOKENCLAIMSRESPONSE = DESCRIPTOR.message_types_by_name['PersistTokenClaimsResponse']
_REVOKETOKENREQUEST = DESCRIPTOR.message_types_by_name['RevokeTokenRequest']
_REVOKETOKENREQUESTRESPONSE = DESCRIPTOR.message_types_by_name['RevokeTokenRequestResponse']
GenerateTokenRequest = _reflection.GeneratedProtocolMessageType('GenerateTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERATETOKENREQUEST,
  '__module__' : 'qwak.ecosystem.jfrog.v0.token_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.ecosystem.jfrog.token.v0.GenerateTokenRequest)
  })
_sym_db.RegisterMessage(GenerateTokenRequest)

GenerateTokenResponse = _reflection.GeneratedProtocolMessageType('GenerateTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENERATETOKENRESPONSE,
  '__module__' : 'qwak.ecosystem.jfrog.v0.token_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.ecosystem.jfrog.token.v0.GenerateTokenResponse)
  })
_sym_db.RegisterMessage(GenerateTokenResponse)

GenerateArtifactoryImagePullTokenRequest = _reflection.GeneratedProtocolMessageType('GenerateArtifactoryImagePullTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEARTIFACTORYIMAGEPULLTOKENREQUEST,
  '__module__' : 'qwak.ecosystem.jfrog.v0.token_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.ecosystem.jfrog.token.v0.GenerateArtifactoryImagePullTokenRequest)
  })
_sym_db.RegisterMessage(GenerateArtifactoryImagePullTokenRequest)

GenerateArtifactoryImagePullTokenResponse = _reflection.GeneratedProtocolMessageType('GenerateArtifactoryImagePullTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEARTIFACTORYIMAGEPULLTOKENRESPONSE,
  '__module__' : 'qwak.ecosystem.jfrog.v0.token_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.ecosystem.jfrog.token.v0.GenerateArtifactoryImagePullTokenResponse)
  })
_sym_db.RegisterMessage(GenerateArtifactoryImagePullTokenResponse)

PersistTokenClaimsRequest = _reflection.GeneratedProtocolMessageType('PersistTokenClaimsRequest', (_message.Message,), {
  'DESCRIPTOR' : _PERSISTTOKENCLAIMSREQUEST,
  '__module__' : 'qwak.ecosystem.jfrog.v0.token_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.ecosystem.jfrog.token.v0.PersistTokenClaimsRequest)
  })
_sym_db.RegisterMessage(PersistTokenClaimsRequest)

PersistTokenClaimsResponse = _reflection.GeneratedProtocolMessageType('PersistTokenClaimsResponse', (_message.Message,), {
  'DESCRIPTOR' : _PERSISTTOKENCLAIMSRESPONSE,
  '__module__' : 'qwak.ecosystem.jfrog.v0.token_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.ecosystem.jfrog.token.v0.PersistTokenClaimsResponse)
  })
_sym_db.RegisterMessage(PersistTokenClaimsResponse)

RevokeTokenRequest = _reflection.GeneratedProtocolMessageType('RevokeTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _REVOKETOKENREQUEST,
  '__module__' : 'qwak.ecosystem.jfrog.v0.token_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.ecosystem.jfrog.token.v0.RevokeTokenRequest)
  })
_sym_db.RegisterMessage(RevokeTokenRequest)

RevokeTokenRequestResponse = _reflection.GeneratedProtocolMessageType('RevokeTokenRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _REVOKETOKENREQUESTRESPONSE,
  '__module__' : 'qwak.ecosystem.jfrog.v0.token_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.ecosystem.jfrog.token.v0.RevokeTokenRequestResponse)
  })
_sym_db.RegisterMessage(RevokeTokenRequestResponse)

_TOKENSERVICE = DESCRIPTOR.services_by_name['TokenService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.qwak.ai.jfrog.token.v0P\001Z\226\001github.com/qwak-ai/qwak-platform/services/shared/java/libs/qwak-common/qwak-common-api/qwak-platform-ecosystem-api/pb/qwak/ecosystem/jfrog/v0;jfrog_v0'
  _GENERATETOKENREQUEST._serialized_start=115
  _GENERATETOKENREQUEST._serialized_end=204
  _GENERATETOKENRESPONSE._serialized_start=206
  _GENERATETOKENRESPONSE._serialized_end=287
  _GENERATEARTIFACTORYIMAGEPULLTOKENREQUEST._serialized_start=289
  _GENERATEARTIFACTORYIMAGEPULLTOKENREQUEST._serialized_end=413
  _GENERATEARTIFACTORYIMAGEPULLTOKENRESPONSE._serialized_start=415
  _GENERATEARTIFACTORYIMAGEPULLTOKENRESPONSE._serialized_end=516
  _PERSISTTOKENCLAIMSREQUEST._serialized_start=518
  _PERSISTTOKENCLAIMSREQUEST._serialized_end=614
  _PERSISTTOKENCLAIMSRESPONSE._serialized_start=616
  _PERSISTTOKENCLAIMSRESPONSE._serialized_end=662
  _REVOKETOKENREQUEST._serialized_start=664
  _REVOKETOKENREQUEST._serialized_end=764
  _REVOKETOKENREQUESTRESPONSE._serialized_start=766
  _REVOKETOKENREQUESTRESPONSE._serialized_end=794
  _TOKENSERVICE._serialized_start=797
  _TOKENSERVICE._serialized_end=1385
# @@protoc_insertion_point(module_scope)



from abc import ABC, abstractmethod
from dataclasses import dataclass
from typing import Any

from _qwak_proto.qwak.vectors.v1.filters_pb2 import (
    And as ProtoAnd,
    AtomicLiteral as ProtoAtomicLiteral,
    Equal as ProtoEqual,
    Filter as ProtoFilter,
    GreaterThan as ProtoGreaterThan,
    GreaterThanEqual as ProtoGreaterThanEqual,
    IsNotNull as ProtoIsNotNull,
    IsNull as ProtoIsNull,
    LessThan as ProtoLessThan,
    LessThanEqual as ProtoLessThanEqual,
    Like as ProtoLike,
    NotEqual as ProtoNotEqual,
    Or as ProtoOr,
)
from google.protobuf.json_format import MessageToDict, ParseDict
from qwak.vector_store.utils.filter_utils import transform


class Filter(ABC):
    """Abstract base class for filter objects."""

    def And(self, other):
        """Logical AND operation with another filter.

        Usage Example:
        ```
        filter1 = Equal("age", 30)
        filter2 = GreaterThan("score", 90)
        combined_filter = filter1.And(filter2)
        ```
        """
        return And(self, other)

    def Or(self, other):
        """Logical OR operation with another filter.

        Usage Example:
        ```
        filter1 = Equal("age", 30)
        filter2 = GreaterThan("score", 90)
        combined_filter = filter1.Or(filter2)
        ```
        """
        return Or(self, other)

    @abstractmethod
    def _to_proto(self):
        """Convert the filter to a protobuf representation."""
        pass


@dataclass
class And(Filter):
    """Logical And operation with another filter.

    Usage Example:
    ```
    filter1 = Equal("age", 30)
    filter2 = GreaterThan("score", 90)
    combined_filter = And(left=filter1, right=filter2)
    ```
    """

    left: Filter
    right: Filter

    def _to_proto(self):
        proto_filter = ProtoFilter()
        proto_filter_dict = MessageToDict(proto_filter)
        proto_and_dict = MessageToDict(
            ProtoAnd(left=self.left._to_proto(), right=self.right._to_proto())
        )
        proto_filter_dict["and"] = proto_and_dict
        return ParseDict(proto_filter_dict, proto_filter, ignore_unknown_fields=True)


@dataclass
class Or(Filter):
    """Logical OR operation with another filter.

    Usage Example:
    ```
    filter1 = Equal("age", 30)
    filter2 = GreaterThan("score", 90)
    combined_filter = Or(left=filter1, right=filter2)
    ```
    """

    left: Filter
    right: Filter

    def _to_proto(self):
        proto_filter = ProtoFilter()
        proto_filter_dict = MessageToDict(proto_filter)
        proto_or_dict = MessageToDict(
            ProtoOr(left=self.left._to_proto(), right=self.right._to_proto())
        )
        proto_filter_dict["or"] = proto_or_dict
        return ParseDict(proto_filter_dict, proto_filter, ignore_unknown_fields=True)


@dataclass
class _UnaryFilter(Filter):
    property: str
    value: Any

    def _to_proto(self):
        # Each UnaryFilter implements its own _to_proto
        pass


class Equal(_UnaryFilter):
    """Equal operation.

    Usage Example:
    ```
    filter = Equal(property="age", value=30)
    ```
    """

    def _to_proto(self):
        atomic_literal: ProtoAtomicLiteral = transform(value=self.value)
        return ProtoFilter(eq=ProtoEqual(property=self.property, value=atomic_literal))


class NotEqual(_UnaryFilter):
    """NotEqual operation.

    Usage Example:
    ```
    filter = NotEqual(property="age", value=30)
    ```
    """

    def _to_proto(self):
        atomic_literal: ProtoAtomicLiteral = transform(value=self.value)
        return ProtoFilter(
            ne=ProtoNotEqual(property=self.property, value=atomic_literal)
        )


class LessThanEqual(_UnaryFilter):
    """LessThanEqual operation.

    Usage Example:
    ```
    filter = LessThanEqual(property="age", value=30)
    ```
    """

    def _to_proto(self):
        atomic_literal: ProtoAtomicLiteral = transform(value=self.value)
        return ProtoFilter(
            lte=ProtoLessThanEqual(property=self.property, value=atomic_literal)
        )


class LessThan(_UnaryFilter):
    """LessThan operation.

    Usage Example:
    ```
    filter = LessThan(property="age", value=30)
    ```
    """

    def _to_proto(self):
        atomic_literal: ProtoAtomicLiteral = transform(value=self.value)
        return ProtoFilter(
            lt=ProtoLessThan(property=self.property, value=atomic_literal)
        )


class GreaterThanEqual(_UnaryFilter):
    """GreaterThanEqual operation.

    Usage Example:
    ```
    filter = GreaterThanEqual(property="age", value=30)
    ```
    """

    def _to_proto(self):
        atomic_literal: ProtoAtomicLiteral = transform(value=self.value)
        return ProtoFilter(
            gte=ProtoGreaterThanEqual(property=self.property, value=atomic_literal)
        )


class GreaterThan(_UnaryFilter):
    """GreaterThan operation.

    Usage Example:
    ```
    filter = GreaterThan(property="age", value=30)
    ```
    """

    def _to_proto(self):
        atomic_literal: ProtoAtomicLiteral = transform(value=self.value)
        return ProtoFilter(
            gt=ProtoGreaterThan(property=self.property, value=atomic_literal)
        )


@dataclass
class Like(Filter):
    """Like operation.

    Usage Example:
    ```
    filter = Like(property="name", pattern="Tal")
    ```
    """

    property: str
    pattern: str

    def _to_proto(self):
        return ProtoFilter(like=ProtoLike(property=self.property, pattern=self.pattern))


@dataclass
class IsNull(Filter):
    """IsNull operation.

    Usage Example:
    ```
    filter = IsNull(property="zipcode)
    ```
    """

    property: str

    def _to_proto(self):
        return ProtoFilter(is_null=ProtoIsNull(property=self.property))


@dataclass
class IsNotNull(Filter):
    """IsNotNull operation.

    Usage Example:
    ```
    filter = IsNotNull(property="zipcode)
    ```
    """

    property: str

    def _to_proto(self):
        return ProtoFilter(is_not_null=ProtoIsNotNull(property=self.property))


@dataclass
class Property:
    """Represents a property for building filter conditions."""

    name: str

    def gt(self, value: Any):
        """Create a GreaterThan filter for this property.

        Usage Example:
        ```
        filter = Property("age").gt(30)
        ```
        """
        return GreaterThan(self.name, value)

    def gte(self, value: Any):
        """Create a GreaterThanEqual filter for this property.

        Usage Example:
        ```
        filter = Property("score").gte(90)
        ```
        """
        return GreaterThanEqual(self.name, value)

    def lt(self, value: Any):
        """Create a LessThan filter for this property.

        Usage Example:
        ```
        filter = Property("age").lt(30)
        ```
        """
        return LessThan(self.name, value)

    def lte(self, value: Any):
        """Create a LessThanEqual filter for this property.

        Usage Example:
        ```
        filter = Property("score").lte(90)
        ```
        """
        return LessThanEqual(self.name, value)

    def eq(self, value: Any):
        """Create an Equal filter for this property.

        Usage Example:
        ```
        filter = Property("score").eq(90)
        ```
        """
        return Equal(self.name, value)

    def ne(self, value: Any):
        """Create an NotEqual filter for this property.

        Usage Example:
        ```
        filter = Property("age").ne(30)
        ```
        """
        return NotEqual(self.name, value)

    def is_null(self):
        """Create an IsNull filter for this property.

        Usage Example:
        ```
        filter = Property("zipcode").is_null()
        ```
        """
        return IsNull(self.name)

    def is_not_null(self):
        """Create an IsNotNull filter for this property.

        Usage Example:
        ```
        filter = Property("zipcode").is_not_null()
        ```
        """
        return IsNotNull(self.name)

    def like(self, pattern: str):
        """Create a Like filter for this property.

        Usage Example:
        ```
        filter = Property("name").like("Tal")
        ```
        """
        return Like(self.name, pattern)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/model_descriptor/open_ai_descriptor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.qwak/model_descriptor/open_ai_descriptor.proto\x12#qwak.llmops.model_descriptor.openai\x1a\x1cgoogle/protobuf/struct.proto\"f\n\x18OpenAIProviderDescriptor\x12J\n\x06models\x18\x01 \x03(\x0b\x32:.qwak.llmops.model_descriptor.openai.OpenAIModelDescriptor\"x\n\x15OpenAIModelDescriptor\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12M\n\x0c\x63\x61pabilities\x18\x02 \x01(\x0b\x32\x37.qwak.llmops.model_descriptor.openai.OpenAICapabilities\"\xaf\x06\n\x15OpenAIChatModelParams\x12\x1b\n\x11\x66requency_penalty\x18\x01 \x01(\x01H\x00\x12-\n\nlogit_bias\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructH\x01\x12\x12\n\x08logprobs\x18\x03 \x01(\x08H\x02\x12\x14\n\nmax_tokens\x18\x04 \x01(\x03H\x03\x12\x0b\n\x01n\x18\x05 \x01(\x05H\x04\x12\x1a\n\x10presence_penalty\x18\x06 \x01(\x01H\x05\x12\x19\n\x0fresponse_format\x18\x07 \x01(\tH\x06\x12\x0e\n\x04seed\x18\x08 \x01(\x05H\x07\x12*\n\x04stop\x18\t \x01(\x0b\x32\x1a.google.protobuf.ListValueH\x08\x12\x15\n\x0btemperature\x18\n \x01(\x01H\t\x12\x46\n\x0btool_choice\x18\x0b \x01(\x0b\x32/.qwak.llmops.model_descriptor.openai.ToolChoiceH\n\x12@\n\ntools_spec\x18\x0c \x01(\x0b\x32*.qwak.llmops.model_descriptor.openai.ToolsH\x0b\x12\x16\n\x0ctop_logprobs\x18\r \x01(\x05H\x0c\x12\x0f\n\x05top_p\x18\x0e \x01(\x01H\r\x12\x0e\n\x04user\x18\x0f \x01(\tH\x0e\x42\x1c\n\x1aoptional_frequency_penaltyB\x15\n\x13optional_logit_biasB\x13\n\x11optional_logprobsB\x15\n\x13optional_max_tokensB\x0c\n\noptional_nB\x1b\n\x19optional_presence_penaltyB\x1a\n\x18optional_response_formatB\x0f\n\roptional_seedB\x0f\n\roptional_stopB\x16\n\x14optional_temperatureB\x16\n\x14optional_tool_choiceB\x10\n\x0eoptional_toolsB\x17\n\x15optional_top_logprobsB\x10\n\x0eoptional_top_pB\x0f\n\roptional_user\"/\n\x05Tools\x12&\n\x05tools\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct\"V\n\nToolChoice\x12\'\n\x04json\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x12\x11\n\x07literal\x18\x02 \x01(\tH\x00\x42\x0c\n\nvalue_type\"m\n\x12OpenAICapabilities\x12\x46\n\x08\x63hat_api\x18\x01 \x01(\x0b\x32\x32.qwak.llmops.model_descriptor.openai.OpenAIChatAPIH\x00\x42\x0f\n\roptional_chat\"z\n\rOpenAIChatAPI\x12Q\n\x0b\x63hat_params\x18\x01 \x01(\x0b\x32:.qwak.llmops.model_descriptor.openai.OpenAIChatModelParamsH\x00\x42\x16\n\x14optional_chat_paramsB.\n*com.qwak.ai.llmops.model_descriptor.openaiP\x01\x62\x06proto3')



_OPENAIPROVIDERDESCRIPTOR = DESCRIPTOR.message_types_by_name['OpenAIProviderDescriptor']
_OPENAIMODELDESCRIPTOR = DESCRIPTOR.message_types_by_name['OpenAIModelDescriptor']
_OPENAICHATMODELPARAMS = DESCRIPTOR.message_types_by_name['OpenAIChatModelParams']
_TOOLS = DESCRIPTOR.message_types_by_name['Tools']
_TOOLCHOICE = DESCRIPTOR.message_types_by_name['ToolChoice']
_OPENAICAPABILITIES = DESCRIPTOR.message_types_by_name['OpenAICapabilities']
_OPENAICHATAPI = DESCRIPTOR.message_types_by_name['OpenAIChatAPI']
OpenAIProviderDescriptor = _reflection.GeneratedProtocolMessageType('OpenAIProviderDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _OPENAIPROVIDERDESCRIPTOR,
  '__module__' : 'qwak.model_descriptor.open_ai_descriptor_pb2'
  # @@protoc_insertion_point(class_scope:qwak.llmops.model_descriptor.openai.OpenAIProviderDescriptor)
  })
_sym_db.RegisterMessage(OpenAIProviderDescriptor)

OpenAIModelDescriptor = _reflection.GeneratedProtocolMessageType('OpenAIModelDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _OPENAIMODELDESCRIPTOR,
  '__module__' : 'qwak.model_descriptor.open_ai_descriptor_pb2'
  # @@protoc_insertion_point(class_scope:qwak.llmops.model_descriptor.openai.OpenAIModelDescriptor)
  })
_sym_db.RegisterMessage(OpenAIModelDescriptor)

OpenAIChatModelParams = _reflection.GeneratedProtocolMessageType('OpenAIChatModelParams', (_message.Message,), {
  'DESCRIPTOR' : _OPENAICHATMODELPARAMS,
  '__module__' : 'qwak.model_descriptor.open_ai_descriptor_pb2'
  # @@protoc_insertion_point(class_scope:qwak.llmops.model_descriptor.openai.OpenAIChatModelParams)
  })
_sym_db.RegisterMessage(OpenAIChatModelParams)

Tools = _reflection.GeneratedProtocolMessageType('Tools', (_message.Message,), {
  'DESCRIPTOR' : _TOOLS,
  '__module__' : 'qwak.model_descriptor.open_ai_descriptor_pb2'
  # @@protoc_insertion_point(class_scope:qwak.llmops.model_descriptor.openai.Tools)
  })
_sym_db.RegisterMessage(Tools)

ToolChoice = _reflection.GeneratedProtocolMessageType('ToolChoice', (_message.Message,), {
  'DESCRIPTOR' : _TOOLCHOICE,
  '__module__' : 'qwak.model_descriptor.open_ai_descriptor_pb2'
  # @@protoc_insertion_point(class_scope:qwak.llmops.model_descriptor.openai.ToolChoice)
  })
_sym_db.RegisterMessage(ToolChoice)

OpenAICapabilities = _reflection.GeneratedProtocolMessageType('OpenAICapabilities', (_message.Message,), {
  'DESCRIPTOR' : _OPENAICAPABILITIES,
  '__module__' : 'qwak.model_descriptor.open_ai_descriptor_pb2'
  # @@protoc_insertion_point(class_scope:qwak.llmops.model_descriptor.openai.OpenAICapabilities)
  })
_sym_db.RegisterMessage(OpenAICapabilities)

OpenAIChatAPI = _reflection.GeneratedProtocolMessageType('OpenAIChatAPI', (_message.Message,), {
  'DESCRIPTOR' : _OPENAICHATAPI,
  '__module__' : 'qwak.model_descriptor.open_ai_descriptor_pb2'
  # @@protoc_insertion_point(class_scope:qwak.llmops.model_descriptor.openai.OpenAIChatAPI)
  })
_sym_db.RegisterMessage(OpenAIChatAPI)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*com.qwak.ai.llmops.model_descriptor.openaiP\001'
  _OPENAIPROVIDERDESCRIPTOR._serialized_start=117
  _OPENAIPROVIDERDESCRIPTOR._serialized_end=219
  _OPENAIMODELDESCRIPTOR._serialized_start=221
  _OPENAIMODELDESCRIPTOR._serialized_end=341
  _OPENAICHATMODELPARAMS._serialized_start=344
  _OPENAICHATMODELPARAMS._serialized_end=1159
  _TOOLS._serialized_start=1161
  _TOOLS._serialized_end=1208
  _TOOLCHOICE._serialized_start=1210
  _TOOLCHOICE._serialized_end=1296
  _OPENAICAPABILITIES._serialized_start=1298
  _OPENAICAPABILITIES._serialized_end=1407
  _OPENAICHATAPI._serialized_start=1409
  _OPENAICHATAPI._serialized_end=1531
# @@protoc_insertion_point(module_scope)



import json
from datetime import datetime

import grpc
import pandas as pd
from _qwak_proto.qwak.feature_store.serving.serving_pb2 import (
    MultiFeatureValuesResponse,
)
from _qwak_proto.qwak.feature_store.serving.serving_pb2_grpc import (
    ServingServiceServicer,
)
from qwak.exceptions import QwakException


class NpEncoder(json.JSONEncoder):
    def default(self, obj):
        import numpy as np

        if isinstance(obj, np.integer):
            return int(obj)
        if isinstance(obj, np.floating):
            return float(obj)
        if isinstance(obj, np.ndarray):
            return obj.tolist()
        if isinstance(obj, datetime):
            return obj.isoformat()
        return super(NpEncoder, self).default(obj)


class ServingServiceMock(ServingServiceServicer):
    def __init__(self):
        self.features_by_entity_df = {}
        self._fail_request_ledger = 0

    def fail_next_request(self):
        self._fail_request_ledger += 1

    def upsert_features(self, entity_name, features_df):
        if entity_name not in features_df.columns:
            raise QwakException("Entity name does not exist in the data frame columns")

        entity_feature_df = self.features_by_entity_df.get(
            entity_name, pd.DataFrame(columns=[entity_name])
        )

        self.features_by_entity_df[entity_name] = (
            features_df.set_index(entity_name)
            .combine_first(entity_feature_df.set_index(entity_name))
            .reset_index()
            .rename({"index": entity_name})
        )

    def GetMultiFeatures(self, request, context) -> MultiFeatureValuesResponse:
        if self._fail_request_ledger > 0:
            self._fail_request_ledger -= 1
            raise ValueError("Test failing feature request!")

        if not self._validate_supported_features(request):
            context.set_code(grpc.StatusCode.UNIMPLEMENTED)
            context.set_details("Received an unimplemented one-of type for feature")
            return MultiFeatureValuesResponse()

        indexes, all_values, columns = [], [], []
        for row_index, entity_values in enumerate(request.entity_values_matrix.rows):
            values = []
            for index, entity_name in enumerate(
                request.entity_values_matrix.header.entity_names
            ):
                entity_feature_df = self.features_by_entity_df.get(entity_name)
                if entity_feature_df is not None:
                    all_features = self._filter_features(
                        entity_feature_df, entity_name, entity_values, index
                    )

                    if len(all_features) > 1:
                        context.set_code(grpc.StatusCode.INTERNAL)
                        context.set_details(
                            "Invalid state, a single entity has multiple feature rows - bug in the store :~("
                        )
                        return MultiFeatureValuesResponse()

                    elif len(all_features) == 1:
                        columns, values = self._populate_data(
                            all_features, columns, entity_name, request, values
                        )

            indexes.append(row_index)
            all_values.append(values)
        result = {"data": all_values, "columns": columns, "index": indexes}

        return MultiFeatureValuesResponse(
            pandas_df_as_json=json.dumps(result, cls=NpEncoder)
        )

    def _populate_data(self, all_features, columns, entity_name, request, values):
        requested_features = set()
        self._populate_requested_features(entity_name, request, requested_features)
        available_features = set(all_features.columns)
        existing_features = requested_features.intersection(available_features)
        non_existing_features = requested_features - available_features
        values = values + (
            [all_features.loc[0, feature_name] for feature_name in existing_features]
        )

        columns = self._populate_existing_values(columns, existing_features)
        columns, values = self._populate_non_existing_values(
            columns, non_existing_features, values
        )
        return columns, values

    def _populate_existing_values(self, columns, existing_features):
        if not any(x in columns for x in list(existing_features)):
            columns = columns + (list(existing_features))
        return columns

    @staticmethod
    def _populate_non_existing_values(columns, non_existing_features, values):
        if not any(x in columns for x in list(non_existing_features)):
            columns = columns + list(non_existing_features)
            for _ in non_existing_features:
                values = values + [None]
        return columns, values

    @staticmethod
    def _populate_requested_features(entity_name, request, requested_features):
        for entity_to_features in request.entities_to_features:
            if entity_to_features.entity_name == entity_name:
                for feature in entity_to_features.features:
                    one_of = feature.WhichOneof("type")
                    if one_of == "batch_feature":
                        requested_features.add(feature.batch_feature.name)
                    elif one_of == "batch_v1_feature":
                        requested_features.add(feature.batch_v1_feature.name)
                    elif one_of == "streaming_v1_feature":
                        requested_features.add(feature.streaming_v1_feature.name)
                    elif one_of == "streaming_feature":
                        requested_features.add(feature.streaming_feature.name)
                    elif one_of == "streaming_aggregation":
                        requested_features.add(feature.streaming_aggregation.name)

    @staticmethod
    def _validate_supported_features(request):
        return all(
            [
                (
                    feature.WhichOneof("type") == "batch_v1_feature"
                    or feature.WhichOneof("type") == "batch_feature"
                    or feature.WhichOneof("type") == "streaming_feature"
                    or feature.WhichOneof("type") == "streaming_feature_v1"
                    or feature.WhichOneof("type") == "streaming_aggregation"
                )
                for entities in request.entities_to_features
                for feature in entities.features
            ]
        )

    @staticmethod
    def _filter_features(entity_feature_df, entity_name, entity_values, index):
        return (
            entity_feature_df[
                entity_feature_df[entity_name].astype(str)
                == str(entity_values.entity_values[index])
            ]
            .drop([entity_name], axis=1)
            .reset_index(drop=True)
        )



from .error_object import ErrorObject as ErrorObject
from .function_definition import FunctionDefinition as FunctionDefinition
from .function_parameters import FunctionParameters as FunctionParameters



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Channel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    CHANNEL_NAME_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """Channel id"""
    channel_name: builtins.str
    """Channel name"""
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        channel_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_id", b"channel_id", "channel_name", b"channel_name"]) -> None: ...

global___Channel = Channel

class FeatureSetAlertType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FAILURE_FIELD_NUMBER: builtins.int
    @property
    def failure(self) -> global___FeatureSetFailureAlert: ...
    def __init__(
        self,
        *,
        failure: global___FeatureSetFailureAlert | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["failure", b"failure", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure", b"failure", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["failure"] | None: ...

global___FeatureSetAlertType = FeatureSetAlertType

class FeatureSetFailureAlert(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNELS_FIELD_NUMBER: builtins.int
    @property
    def channels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Channel]:
        """Channels to alert"""
    def __init__(
        self,
        *,
        channels: collections.abc.Iterable[global___Channel] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channels", b"channels"]) -> None: ...

global___FeatureSetFailureAlert = FeatureSetFailureAlert

class FeatureSetAlertOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    FEATURE_SET_ID_FIELD_NUMBER: builtins.int
    ALERT_TYPES_FIELD_NUMBER: builtins.int
    account_id: builtins.str
    """Account id"""
    account_name: builtins.str
    """Account Name"""
    feature_set_name: builtins.str
    """FeatureSet Name"""
    feature_set_id: builtins.str
    """FeatureSet Id"""
    @property
    def alert_types(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FeatureSetAlertType]:
        """Alert type"""
    def __init__(
        self,
        *,
        account_id: builtins.str = ...,
        account_name: builtins.str = ...,
        feature_set_name: builtins.str = ...,
        feature_set_id: builtins.str = ...,
        alert_types: collections.abc.Iterable[global___FeatureSetAlertType] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "account_name", b"account_name", "alert_types", b"alert_types", "feature_set_id", b"feature_set_id", "feature_set_name", b"feature_set_name"]) -> None: ...

global___FeatureSetAlertOptions = FeatureSetAlertOptions
